@@ -33,10 +33,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x040a00
-pyqt_version_str = "4.10"
+pyqt_version = 0x040a03
+pyqt_version_str = "4.10.3"
 
-sip_min_version = 0x040e03
+sip_min_version = 0x040f00
 
 qt_version = 0
 qt_edition = ""
@@ -46,6 +46,7 @@ qt_incdir = None
 qt_libdir = None
 qt_bindir = None
 qt_datadir = None
+qt_archdatadir = None
 qt_pluginsdir = None
 qt_xfeatures = None
 qt_shared = ""
@@ -276,8 +277,8 @@ def create_optparser():
 
 
 class pyrccMakefile(sipconfig.ProgramMakefile):
-    """This class implements the Makefile for pyrcc.  This is specialised so
-    that pyrcc is automatically run against the examples.
+    """This class implements the Makefile for pyrcc.  This was specialised so
+    that pyrcc was automatically run against the examples (no longer done).
     """
 
     def __init__(self):
@@ -288,28 +289,6 @@ class pyrccMakefile(sipconfig.ProgramMakefile):
                 universal=sipcfg.universal, arch=sipcfg.arch,
                 deployment_target=sipcfg.deployment_target)
 
-    def generate_target_default(self, mfile):
-        """Generate the default target."""
-        sipconfig.ProgramMakefile.generate_target_default(self, mfile)
-
-        # The correct call to pyrcc depends on the Python version.
-        if sys.hexversion >= 0x03000000:
-            flag = "-py3"
-        else:
-            flag = "-py2"
-
-        exe = "$(TARGET)"
-        if sys.platform != 'win32':
-            exe = "./" + exe
-
-        # Find all the .qrc files in the examples.
-        for root, _, files in os.walk("examples"):
-            rel_root = os.path.join("..", root)
-
-            for fn in files:
-                if fn.endswith(".qrc"):
-                    mfile.write("\t%s %s -o %s %s\n" % (exe, flag, os.path.join(rel_root, fn[:-4] + "_rc.py"), os.path.join(rel_root, fn)))
-
 
 class ConfigurePyQt4:
     """This class defines the methods to configure PyQt4.
@@ -377,18 +356,20 @@ class ConfigurePyQt4:
             check_module("QtDBus", "qdbusconnection.h",
                     "QDBusConnection::systemBus()")
 
-        check_module("QtDeclarative", "qdeclarativeview.h",
-                "new QDeclarativeView()")
+        if qt_version < 0x050000 or opts.with_deprecated:
+            check_module("QtDeclarative", "qdeclarativeview.h",
+                    "new QDeclarativeView()")
+            check_module("QtScript", "qscriptengine.h", "new QScriptEngine()")
+            check_module("QtScriptTools", "qscriptenginedebugger.h",
+                    "new QScriptEngineDebugger()")
+            check_module("QtXml", "qdom.h", "new QDomDocument()")
+
         check_module("QtOpenGL", "qgl.h", "new QGLWidget()")
-        check_module("QtScript", "qscriptengine.h", "new QScriptEngine()")
-        check_module("QtScriptTools", "qscriptenginedebugger.h",
-                "new QScriptEngineDebugger()")
         check_module("QtSql", "qsqldatabase.h", "new QSqlDatabase()",
                 extra_libs=sql_libs)
         check_module("QtSvg", "qsvgwidget.h", "new QSvgWidget()")
         check_module("QtTest", "QtTest", "QTest::qSleep(0)")
         check_module("QtWebKit", "qwebpage.h", "new QWebPage()")
-        check_module("QtXml", "qdom.h", "new QDomDocument()")
         check_module("QtXmlPatterns", "qxmlname.h", "new QXmlName()")
         check_module("phonon", "phonon/videowidget.h",
                 "new Phonon::VideoWidget()")
@@ -398,8 +379,6 @@ class ConfigurePyQt4:
 
         if not qt_shared:
             sipconfig.inform("QtDesigner module disabled with static Qt libraries.")
-        elif sipcfg.universal:
-            sipconfig.inform("QtDesigner module disabled with universal binaries.")
         else:
             check_module("QtDesigner", "QExtensionFactory",
                     "new QExtensionFactory()")
@@ -678,22 +657,19 @@ class ConfigurePyQt4:
         for the given module.
 
         mname is the name of the module.
-        lib_name is the normal name of the support library.
+        lib_name is the normal name of the support library.  (Note that this is
+        historical and the unchanged name is always returned.)
         """
         qpy_dir = os.path.join("qpy", mname)
 
         if sys.platform == 'win32':
             if opts.debug:
                 qpy_lib_dir = os.path.join(qpy_dir, "debug")
-                lib_name = 'd' + lib_name
             else:
                 qpy_lib_dir = os.path.join(qpy_dir, "release")
         else:
             qpy_lib_dir = qpy_dir
 
-            if sys.platform == 'darwin' and opts.debug:
-                lib_name += '_debug'
-
         return os.path.join(src_dir, qpy_dir), os.path.abspath(qpy_lib_dir), lib_name
 
     def _static_plugins(self, mname):
@@ -935,45 +911,41 @@ include(%s)
         makefile.generate()
         tool.append("pyuic")
 
-        if "QtXml" in pyqt_modules:
-            sipconfig.inform("Creating pylupdate4 Makefile...")
+        sipconfig.inform("Creating pylupdate4 Makefile...")
 
-            cxxflags_app = sipcfg.build_macros().get("CXXFLAGS_APP", "")
+        cxxflags_app = sipcfg.build_macros().get("CXXFLAGS_APP", "")
 
-            makefile = sipconfig.ProgramMakefile(
-                configuration=sipcfg,
-                build_file=os.path.join(src_dir, "pylupdate", "pylupdate.sbf"),
-                dir="pylupdate",
-                install_dir=opts.pyqtbindir,
-                console=1,
-                qt=["QtCore", "QtXml"],
-                debug=opts.debug,
-                warnings=1,
-                universal=sipcfg.universal,
-                arch=sipcfg.arch,
-                deployment_target=sipcfg.deployment_target
-            )
+        makefile = sipconfig.ProgramMakefile(
+            configuration=sipcfg,
+            build_file=os.path.join(src_dir, "pylupdate", "pylupdate.sbf"),
+            dir="pylupdate",
+            install_dir=opts.pyqtbindir,
+            console=1,
+            qt=["QtCore", "QtXml"],
+            debug=opts.debug,
+            warnings=1,
+            universal=sipcfg.universal,
+            arch=sipcfg.arch,
+            deployment_target=sipcfg.deployment_target
+        )
 
-            makefile.extra_include_dirs.append(
-                    os.path.join(src_dir, "pylupdate"))
+        makefile.extra_include_dirs.append(os.path.join(src_dir, "pylupdate"))
 
-            if cxxflags_app != "":
-                makefile.extra_cxxflags.append(cxxflags_app)
+        if cxxflags_app != "":
+            makefile.extra_cxxflags.append(cxxflags_app)
 
-            makefile.generate()
-            tool.append("pylupdate")
+        makefile.generate()
+        tool.append("pylupdate")
 
-            sipconfig.inform("Creating pyrcc4 Makefile...")
+        sipconfig.inform("Creating pyrcc4 Makefile...")
 
-            makefile = pyrccMakefile()
+        makefile = pyrccMakefile()
 
-            if cxxflags_app != "":
-                makefile.extra_cxxflags.append(cxxflags_app)
+        if cxxflags_app != "":
+            makefile.extra_cxxflags.append(cxxflags_app)
 
-            makefile.generate()
-            tool.append("pyrcc")
-        else:
-            sipconfig.inform("pylupdate4 and pyrcc4 will not be built because the Qt XML module is missing.")
+        makefile.generate()
+        tool.append("pyrcc")
 
         if opts.designer_plugin and "QtDesigner" in pyqt_modules:
             py_major = sipcfg.py_version >> 16
@@ -1113,14 +1085,15 @@ def inform_user():
     sipconfig.inform("The Qt header files are in %s." % qt_incdir)
     sipconfig.inform("The %s Qt libraries are in %s." % (lib_type, qt_libdir))
     sipconfig.inform("The Qt binaries are in %s." % qt_bindir)
-    sipconfig.inform("The Qt mkspecs directory is in %s." % qt_datadir)
+    sipconfig.inform("The Qt mkspecs directory is in %s." % qt_archdatadir)
     sipconfig.inform("These PyQt modules will be built: %s." % ", ".join(pyqt_modules))
     sipconfig.inform("The PyQt Python package will be installed in %s." % opts.pyqtmoddir)
 
-    if opts.with_deprecated:
-        sipconfig.inform("PyQt is being built with deprecated Qt v4 features.")
-    else:
-        sipconfig.inform("PyQt is being built without deprecated Qt v4 features.")
+    if qt_version >= 0x050000:
+        if opts.with_deprecated:
+            sipconfig.inform("PyQt is being built with deprecated Qt v4 features.")
+        else:
+            sipconfig.inform("PyQt is being built without deprecated Qt v4 features.")
 
     if opts.no_docstrings:
         sipconfig.inform("PyQt is being built without generated docstrings.")
@@ -1173,6 +1146,7 @@ def create_config(module, template, macros):
         "qt_threaded":        1,
         "qt_dir":             qt_dir,
         "qt_data_dir":        qt_datadir,
+        "qt_archdata_dir":    qt_archdatadir,
         "qt_inc_dir":         qt_incdir,
         "qt_lib_dir":         qt_libdir
     }
@@ -1527,7 +1501,7 @@ def set_sip_flags(pyqt):
         sip_flags.append("-x")
         sip_flags.append("VendorID")
 
-    if not opts.with_deprecated:
+    if qt_version >= 0x050000 and not opts.with_deprecated:
         sip_flags.append("-x")
         sip_flags.append("PyQt_Deprecated_5_0")
 
@@ -1914,19 +1888,19 @@ def get_build_macros(overrides):
 
         if not os.path.dirname(fname):
             qt_macx_spec = fname
-            fname = os.path.join(qt_datadir, "mkspecs", fname)
+            fname = os.path.join(qt_archdatadir, "mkspecs", fname)
     elif sys.platform == "darwin":
         # The Qt Mac binary installer defaults to xcode which we don't want.
         # Use Qt5's macx-clang if it is available, otherwise fall back to
         # macx-g++.
-        fname = os.path.join(qt_datadir, "mkspecs", "macx-clang")
+        fname = os.path.join(qt_archdatadir, "mkspecs", "macx-clang")
         if os.path.isdir(fname):
             qt_macx_spec = "macx-clang"
         else:
-            fname = os.path.join(qt_datadir, "mkspecs", "macx-g++")
+            fname = os.path.join(qt_archdatadir, "mkspecs", "macx-g++")
             qt_macx_spec = "macx-g++"
     else:
-        fname = os.path.join(qt_datadir, "mkspecs", "default")
+        fname = os.path.join(qt_archdatadir, "mkspecs", "default")
 
         # Qt5 doesn't have the 'default' link.
         if not os.path.isdir(fname):
@@ -1936,7 +1910,7 @@ def get_build_macros(overrides):
                 fname = fname.decode()
             f.close()
 
-            fname = os.path.join(qt_datadir, "mkspecs", fname)
+            fname = os.path.join(qt_archdatadir, "mkspecs", fname)
 
     fname = os.path.join(fname, "qmake.conf")
 
@@ -2031,7 +2005,8 @@ def fix_qmake_args(args=""):
 
 def get_qt_configuration():
     """Set the qt_dir, qt_incdir, qt_libdir, qt_bindir, qt_datadir,
-    qt_pluginsdir and qt_xfeatures globals for the Qt installation.
+    qt_archdatadir, qt_pluginsdir and qt_xfeatures globals for the Qt
+    installation.
     """
     sipconfig.inform("Determining the layout of your Qt installation...")
 
@@ -2105,6 +2080,11 @@ int main(int argc, char **argv)
     out << QLibraryInfo::location(QLibraryInfo::LibrariesPath) << '\\n';
     out << QLibraryInfo::location(QLibraryInfo::BinariesPath) << '\\n';
     out << QLibraryInfo::location(QLibraryInfo::DataPath) << '\\n';
+#if QT_VERSION >= 0x050000
+    out << QLibraryInfo::location(QLibraryInfo::ArchDataPath) << '\\n';
+#else
+    out << QLibraryInfo::location(QLibraryInfo::DataPath) << '\\n';
+#endif
     out << QLibraryInfo::location(QLibraryInfo::PluginsPath) << '\\n';
 
     out << QT_VERSION << '\\n';
@@ -2180,8 +2160,9 @@ int main(int argc, char **argv)
     out << "PyQt_NoOpenGLES\\n";
 #endif
 
-    if (sizeof (qreal) != sizeof (double))
-        out << "PyQt_qreal_double\\n";
+#if defined(QT_NO_FPU) || defined(QT_ARCH_ARM) || defined(QT_ARCH_WINDOWSCE) || defined(QT_ARCH_SYMBIAN) || defined(QT_ARCH_VXWORKS)
+    out << "PyQt_qreal_double\\n";
+#endif
 
     return 0;
 }
@@ -2225,7 +2206,8 @@ int main(int argc, char **argv)
     lines = f.read().strip().split("\n")
     f.close()
 
-    global qt_dir, qt_incdir, qt_libdir, qt_bindir, qt_datadir, qt_pluginsdir
+    global qt_dir, qt_incdir, qt_libdir, qt_bindir, qt_datadir, qt_archdatadir
+    global qt_pluginsdir
     global qt_version, qt_edition, qt_licensee, qt_shared, qt_xfeatures
 
     qt_dir = lines[0]
@@ -2233,12 +2215,13 @@ int main(int argc, char **argv)
     qt_libdir = lines[2]
     qt_bindir = lines[3]
     qt_datadir = lines[4]
-    qt_pluginsdir = lines[5]
-    qt_version = lines[6]
-    qt_edition = lines[7]
-    qt_licensee = lines[8]
-    qt_shared = lines[9]
-    qt_xfeatures = lines[10:]
+    qt_archdatadir = lines[5]
+    qt_pluginsdir = lines[6]
+    qt_version = lines[7]
+    qt_edition = lines[8]
+    qt_licensee = lines[9]
+    qt_shared = lines[10]
+    qt_xfeatures = lines[11:]
 
     if opts.assume_shared:
         qt_shared = "shared"
